import React from 'react';
import PropTypes from 'prop-types';
import {
  FLAGS_SVGS_URLS,
  getBankSvgUrls, getFacilitatorSvgUrl,
  getUnknownSvg,
} from './remoteImages';

function getPaymentImage(id, transparent = false) {
  switch (id) {
    case 'amazon':
      return getBankSvgUrls('amazon', transparent);
    case 'amex':
      return FLAGS_SVGS_URLS.amex;
    case 'aura':
      return FLAGS_SVGS_URLS.aura;
    case 'cirrus':
      return FLAGS_SVGS_URLS.cirrus;
    case 'diners':
      return FLAGS_SVGS_URLS.diners;
    case 'direct_debit':
      return FLAGS_SVGS_URLS.direct_debit;
    case 'discover':
      return FLAGS_SVGS_URLS.discover;
    case 'ebay':
      return FLAGS_SVGS_URLS.ebay;
    case 'elo':
      return FLAGS_SVGS_URLS.elo;
    case 'eway':
      return FLAGS_SVGS_URLS.eway;
    case 'jcb':
      return FLAGS_SVGS_URLS.jcb;
    case 'maestro':
      return FLAGS_SVGS_URLS.maestro;
    case 'mastercard':
      return FLAGS_SVGS_URLS.mastercard;
    case 'paypal':
      return getFacilitatorSvgUrl('paypal', transparent);
    case 'sage':
      return FLAGS_SVGS_URLS.sage;
    case 'shopify':
      return FLAGS_SVGS_URLS.shopify;
    case 'skrill_moneybookers':
      return FLAGS_SVGS_URLS.skrill_moneybookers;
    case 'skrill':
      return FLAGS_SVGS_URLS.skrill;
    case 'solo':
      return FLAGS_SVGS_URLS.solo;
    case 'visa_electron':
      return FLAGS_SVGS_URLS.visa_electron;
    case 'visa':
      return FLAGS_SVGS_URLS.visa;
    case 'wallet':
      return getFacilitatorSvgUrl('wallet', transparent);
    case 'western':
      return FLAGS_SVGS_URLS.western;
    case 'worldpay':
      return FLAGS_SVGS_URLS.worldpay;
    case 'boleto':
      return getBankSvgUrls('boleto', transparent);
    case 'cielo':
      return getFacilitatorSvgUrl('cielo', transparent);
    case 'elavon':
      return getFacilitatorSvgUrl('elavon', transparent);
    case 'global':
      return getFacilitatorSvgUrl('global', transparent);
    case 'pagseguro':
      return getFacilitatorSvgUrl('pagseguro', transparent);
    case 'rede':
      return getFacilitatorSvgUrl('rede', transparent);
    case 'stone':
      return getFacilitatorSvgUrl('stone', transparent);
    case 'bb':
      return getBankSvgUrls('bb', transparent);
    case 'bradesco':
      return getBankSvgUrls('bradesco', transparent);
    case 'caixa':
      return getBankSvgUrls('caixa', transparent);
    case 'hsbc':
      return getBankSvgUrls('hsbc', transparent);
    case 'itau':
      return getBankSvgUrls('itau', transparent);
    case 'santander':
      return getBankSvgUrls('santander', transparent);
    default:
      return getUnknownSvg('generic', transparent);
  }
}

const PaymentIcon = ({
  style, className,
  id, transparent,
}) => (
  <img
    src={getPaymentImage(id, transparent)}
    style={style}
    className={className}
    alt={`${id} payment icon`}
  />
);

PaymentIcon.propTypes = {
  style: PropTypes.object,
  className: PropTypes.string,
  id: PropTypes.string.isRequired,
  transparent: PropTypes.bool,
};

PaymentIcon.defaultProps = {
  transparent: false,
  style: {},
  className: '',
};

export default PaymentIcon;
